Chat with Assistant - MindRoot 9.10.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Chat with Assistant

- On the home page, click the Assistant button.

- A new tab will open with a chat UI.

- Try requesting something from the assistant, for example:

  “Create a mood tracker table showing daily activities with emoji ratings and star scores for each day of the work week.”

(Note: shown is typical output from DeepSeek Chat 3.1)